==> haskell-hspec-contrib-0.5.1-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-contrib
version:              0.5.1
visibility:           public
id:                   hspec-contrib-0.5.1-2fZ9Tvx01Fx1g6eJdTlVZO
key:                  hspec-contrib-0.5.1-2fZ9Tvx01Fx1g6eJdTlVZO
license:              MIT
copyright:
    (c) 2011-2018 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  83acc7f7489a1f97b0ebf1f84f8a2474
exposed:              True
exposed-modules:      Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs:          /usr/lib/ghc-8.8.1/site-local/hspec-contrib-0.5.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/hspec-contrib-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/hspec-contrib-0.5.1
hs-libraries:         HShspec-contrib-0.5.1-2fZ9Tvx01Fx1g6eJdTlVZO
depends:
    HUnit-1.6.0.0-82Oeq4zGJ5SXDJrZFa63t base-4.13.0.0
    hspec-core-2.7.1-4akAZXEddtXABBZAejkUHw

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-contrib-0.5.1-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-contrib
version:              0.5.1
visibility:           public
id:                   hspec-contrib-0.5.1-5kBp86lptY12D2JgkGjVGj
key:                  hspec-contrib-0.5.1-5kBp86lptY12D2JgkGjVGj
license:              MIT
copyright:
    (c) 2011-2018 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  8501c7ebab4e2675b95e37fbaf5eed2a
exposed:              True
exposed-modules:      Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs:          /usr/lib/ghc-8.8.1/site-local/hspec-contrib-0.5.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/hspec-contrib-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/hspec-contrib-0.5.1
hs-libraries:         HShspec-contrib-0.5.1-5kBp86lptY12D2JgkGjVGj
depends:
    HUnit-1.6.0.0-82Oeq4zGJ5SXDJrZFa63t base-4.13.0.0
    hspec-core-2.7.1-7M9CU6QcmuhAvneP9W2gHD

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
